==> nuntio_hera-0.1.0.tar.gz: lib/hera_app/ProfilePage/profile_avatar/profile_avatar.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera/hera.dart';

class ProfileAvatar extends StatelessWidget {
  ProfileAvatar({
    Key? key,
    this.radius = 20,
    this.borderColor = Colors.transparent,
    this.borderRadius = 0,
    this.textStyle = const TextStyle(
        color: CupertinoColors.white,
        fontSize: 11,
        fontWeight: FontWeight.w500),
    this.onClick,
  }) : super(key: key);

  final double radius;
  final Color borderColor;
  final double borderRadius;
  final Function? onClick;
  final TextStyle textStyle;

  Widget getGestureDetector({required Widget child}) {
    if (onClick == null) {
      return child;
    }
    return GestureDetector(
      onTap: () {
        onClick!();
      },
      child: child,
    );
  }

  Widget getIdentifier() {
    if (Hera.currentUser().profile.firstName.isNotEmpty &&
        Hera.currentUser().profile.lastName.isNotEmpty) {
      return Text(
        "${Hera.currentUser().profile.firstName[0] + Hera.currentUser().profile.lastName[0]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    } else if (Hera.currentUser().username.isNotEmpty &&
        Hera.currentUser().username.length >= 2) {
      return Text(
        "${Hera.currentUser().username[0] + Hera.currentUser().username[1]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    } else if (Hera.currentUser().contactInfo.email.isNotEmpty &&
        Hera.currentUser().contactInfo.email.split("@").length == 2) {
      var email = Hera.currentUser().contactInfo.email.split("@");
      return Text(
        "${email[0][0] + email[1][0]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    }
    return Icon(
      CupertinoIcons.person,
      color: CupertinoColors.white,
      size: radius * 1.4,
    );
  }

  @override
  Widget build(BuildContext context) {
    return getGestureDetector(
      child: SizedBox(
        width: radius * 2,
        height: radius * 2,
        child: CachedNetworkImage(
          imageUrl: Hera.currentUser().profile.profileImage,
          imageBuilder: (context, imageProvider) => Container(
            width: radius * 2,
            height: radius * 2,
            decoration: BoxDecoration(
              color: Colors.transparent,
              border: Border.all(
                color: borderColor,
                width: borderRadius,
              ),
              borderRadius: BorderRadius.circular(100),
              image: DecorationImage(
                image: imageProvider,
                fit: BoxFit.cover,
              ),
            ),
          ),
          errorWidget: (context, url, error) {
            print(error.toString());
            return Container(
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  colors: [
                    Color(0xff007FFE),
                    Color(0xff0162C4),
                  ],
                  begin: Alignment.topLeft,
                  end: Alignment.bottomRight,
                ),
                border: Border.all(
                  color: borderColor,
                  width: borderRadius,
                ),
                borderRadius: BorderRadius.circular(100),
              ),
              width: radius * 2,
              height: radius * 2,
              child: Center(child: getIdentifier()),
            );
          },
        ),
      ),
    );
  }
}

==> nuntio_hera-0.1.10.tar.gz: lib/hera_app/ProfilePage/profile_avatar/profile_avatar.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera/hera.dart';

class ProfileAvatar extends StatelessWidget {
  ProfileAvatar({
    Key? key,
    this.radius = 20,
    this.borderColor = Colors.transparent,
    this.borderRadius = 0,
    this.textStyle = const TextStyle(
        color: CupertinoColors.white,
        fontSize: 11,
        fontWeight: FontWeight.w500),
    this.onClick,
  }) : super(key: key);

  final double radius;
  final Color borderColor;
  final double borderRadius;
  final Function? onClick;
  final TextStyle textStyle;

  Widget getGestureDetector({required Widget child}) {
    if (onClick == null) {
      return child;
    }
    return GestureDetector(
      onTap: () {
        onClick!();
      },
      child: child,
    );
  }

  Widget getIdentifier() {
    if (Hera.currentUser().profile.firstName.isNotEmpty &&
        Hera.currentUser().profile.lastName.isNotEmpty) {
      return Text(
        "${Hera.currentUser().profile.firstName[0] + Hera.currentUser().profile.lastName[0]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    } else if (Hera.currentUser().username.isNotEmpty &&
        Hera.currentUser().username.length >= 2) {
      return Text(
        "${Hera.currentUser().username[0] + Hera.currentUser().username[1]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    } else if (Hera.currentUser().contactInfo.email.isNotEmpty &&
        Hera.currentUser().contactInfo.email.split("@").length == 2) {
      var email = Hera.currentUser().contactInfo.email.split("@");
      return Text(
        "${email[0][0] + email[1][0]}",
        textAlign: TextAlign.center,
        style: textStyle,
      );
    }
    return Icon(
      CupertinoIcons.person,
      color: CupertinoColors.white,
      size: radius * 1.4,
    );
  }

  @override
  Widget build(BuildContext context) {
    return getGestureDetector(
      child: SizedBox(
        width: radius * 2,
        height: radius * 2,
        child: CachedNetworkImage(
          imageUrl: Hera.currentUser().profile.profileImage.url,
          imageBuilder: (context, imageProvider) => Container(
            width: radius * 2,
            height: radius * 2,
            decoration: BoxDecoration(
              color: Colors.transparent,
              border: Border.all(
                color: borderColor,
                width: borderRadius,
              ),
              borderRadius: BorderRadius.circular(100),
              image: DecorationImage(
                image: imageProvider,
                fit: BoxFit.cover,
              ),
            ),
          ),
          errorWidget: (context, url, error) {
            print(error.toString());
            return Container(
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  colors: [
                    Color(0xff007FFE),
                    Color(0xff0162C4),
                  ],
                  begin: Alignment.topLeft,
                  end: Alignment.bottomRight,
                ),
                border: Border.all(
                  color: borderColor,
                  width: borderRadius,
                ),
                borderRadius: BorderRadius.circular(100),
              ),
              width: radius * 2,
              height: radius * 2,
              child: Center(child: getIdentifier()),
            );
          },
        ),
      ),
    );
  }
}
